############
Internal API
############

.. autoclass:: Individual::Individual
    :noindex:
    :special-members:
    :exclude-members: __weakref__
    :member-order: bysource
    :members:

.. autoclass:: CustomExceptions::Error
    :noindex:
    :special-members:
    :exclude-members: __weakref__
    :member-order: bysource
    :members:

.. autoclass:: CustomExceptions::IncorrectValueError
    :noindex:
    :special-members:
    :exclude-members: __weakref__
    :member-order: bysource
    :members:
